processorconfig – BRDR - Aligning borders

# ProcessorConfig

    configs.ProcessorConfig(
        multi_as_single_modus=True,
        max_outer_buffer=50,
        od_strategy=OpenDomainStrategy.SNAP_ALL_SIDE,
        threshold_overlap_percentage=50,
        threshold_exclusion_area=0,
        threshold_exclusion_percentage=0,
        threshold_inclusion_percentage=100,
        buffer_multiplication_factor=1.01,
        threshold_circle_ratio=0.98,
        snap_strategy=SnapStrategy.PREFER_VERTICES,
        snap_max_segment_length=2,
        partial_snapping=False,
        partial_snap_strategy=SnapStrategy.PREFER_VERTICES,
        partial_snap_max_segment_length=2,
        area_limit=None,
    )

Configuration for the geometric preprocessing of polygons in the brdr pipeline.

## Parameters

Name | Type | Description | Default
--- | --- | --- | ---
multi_as_single_modus | bool | Modus to handle multipolygons. If True, input multipolygons are split into single polygons for processing and merged back afterward. If False, multipolygons are processed as a single unit. | `True`
max_outer_buffer | int | Value that is used to calculate the boundary of a thematic geometry wherefor the calculation has to be done. (inner part is added) | `50`
od_strategy | OpenDomainStrategy | The strategy used to determine how to handle information outside the reference polygons (Open Domain). | `OpenDomainStrategy.SNAP_ALL_SIDE`
threshold_overlap_percentage | int | Threshold (%) to determine if a reference polygon should be included when no relevant intersections or differences exist. If set to -1, the original border is returned in such cases. | `50`
threshold_exclusion_area | int | Area in square meters (\(m^2\)) below which candidate reference polygons are excluded from processing. | `0`
threshold_exclusion_percentage | int | Overlap percentage below which candidate reference polygons are excluded. | `0`
threshold_inclusion_percentage | int | Percentage threshold above which a reference polygon is automatically included in the alignment process. | `100`
buffer_multiplication_factor | float | Factor used to buffer thematic objects when searching for reference borders (buffer = factor * relevant_distance). | `1.01`
threshold_circle_ratio | float | Threshold to exclude circular geometries based on the Polsby-Popper algorithm (where 1.0 is a perfect circle). | `0.98`
snap_strategy | SnapStrategy | The primary strategy used for snapping geometry vertices to the reference. When alignment is done by ‘SnapGeometryProcessor’, This strategy will be applied | `SnapStrategy.PREFER_VERTICES`
snap_max_segment_length | int | The maximum segment length allowed during the snapping process. When alignment is done by ‘SnapGeometryProcessor’, the input geometry (line, lineair ring,…) will be split up by default in parts of max X meter | `2`
partial_snapping | bool | Whether to allow snapping of individual segments rather than the entire geometry. | `False`
partial_snap_strategy | SnapStrategy | The strategy used specifically for partial snapping operations. When snapping of partial geometries (geom_x) is executed, This strategy will be applied. | `SnapStrategy.PREFER_VERTICES`
partial_snap_max_segment_length | int | The maximum segment length allowed during partial snapping. When real snapping of vertices is used, the input geometry will be split up by default in parts of max X meter | `2`
area_limit | int | Maximum area for processing. If a polygon exceeds this limit, it may be skipped or simplified. | `None`